ContainedButtonColor enum

Inheritance
Available extensions

Values

brand → const ContainedButtonColor
colorDefault → const ContainedButtonColor
danger → const ContainedButtonColor
warning → const ContainedButtonColor

Properties

backgroundColor → Color

Available on ContainedButtonColor, provided by the ContainedButtonColorsExtension extension

no setter
fontColor → Color

Available on ContainedButtonColor, provided by the ContainedButtonColorsExtension extension

no setter
hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
pressedBackgroundColor → Color

Available on ContainedButtonColor, provided by the ContainedButtonColorsExtension extension

no setter
pressedColor → Color

Available on ContainedButtonColor, provided by the ContainedButtonColorsExtension extension

no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<ContainedButtonColor>
A constant List of the values in this enum, in order of their declaration.