HideAnimation class

Constructors

HideAnimation()

Properties

focusNode → FocusNode
final
hashCode → int
The hash code for this object.
no setterinherited
keyAppBar → GlobalKey<State<StatefulWidget>>
final
keyInputFocus → GlobalKey<State<StatefulWidget>>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scrollController → ScrollController
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited